@@ -253,9 +253,16 @@ class NewRelicAlerts(object):
         # Update AlertPolicy object
         self.populate_alert_policy_values(policy, service_type)
         self.add_alert_policy_to_notification_channels(policy)
-        self.add_policy_to_opsgenie_channel(policy, opsgenie_team)
         self.replace_symbols_in_condition(policy)
 
+        # Configure Opsgenie notifications for services running in the production account
+        try:
+          prod_account = EFConfig.ENV_ACCOUNT_MAP['prod']
+          if self.context.env in ["prod", "global.{}".format(prod_account), "mgmt.{}".format(prod_account)]:
+            self.add_policy_to_opsgenie_channel(policy, opsgenie_team)
+        except KeyError:
+          pass
+
         # Infra alert conditions
         policy = self.override_infra_alert_condition_values(policy, service_alert_overrides)
         policy = self.delete_conditions_not_matching_config_values(policy)
